@@ -1,8 +1,8 @@
 /*
 **  OSSP xds - Extensible Data Serialization
-**  Copyright (c) 2001-2003 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2001-2003 The OSSP Project <http://www.ossp.org/>
-**  Copyright (c) 2001-2003 Cable & Wireless Germany <http://www.cw.com/de/>
+**  Copyright (c) 2001-2004 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2001-2004 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2001-2004 Cable & Wireless <http://www.cw.com/>
 **
 **  This file is part of OSSP xds, an extensible data serialization
 **  library which can be found at http://www.ossp.org/pkg/lib/xds/.
@@ -377,7 +377,7 @@ int xdr_encode_float(xds_t *xds, void *engine_context,
 		     void *buffer, size_t buffer_size,
 		     size_t *used_buffer_size, va_list *args)
 {
-    myfloat_t   value;
+    myfloat_t   value = { 0, 0, 0 };
     xds_uint8_t tmp;
 
     xds_init_encoding_engine(4);
@@ -536,7 +536,7 @@ int xdr_encode_double(xds_t *xds, void *engine_context,
 		     void *buffer, size_t buffer_size,
 		     size_t *used_buffer_size, va_list *args)
 {
-    mydouble_t   value;
+    mydouble_t   value = { 0, 0, 0 };
     xds_uint16_t tmp;
 
     xds_init_encoding_engine(8);
