@@ -1,8 +1,8 @@
 /*
 **  OSSP xds - Extensible Data Serialization
-**  Copyright (c) 2001-2003 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2001-2003 The OSSP Project <http://www.ossp.org/>
-**  Copyright (c) 2001-2003 Cable & Wireless Germany <http://www.cw.com/de/>
+**  Copyright (c) 2001-2004 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2001-2004 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2001-2004 Cable & Wireless <http://www.cw.com/>
 **
 **  This file is part of OSSP xds, an extensible data serialization
 **  library which can be found at http://www.ossp.org/pkg/lib/xds/.
@@ -434,14 +434,17 @@ int xml_encode_float(xds_t *xds, void *engine_context,
 int xml_decode_float(xds_t *xds, void *engine_context,
                       void *buffer, size_t buffer_size,
                       size_t *used_buffer_size, va_list *args)
-    {
+{
+    int size;
     xds_init_decoding_engine(7 + 8 + 1);
     if (sscanf(buffer, "<float>%f</float>%n",
-	       va_arg(*args, float*), used_buffer_size) != 1)
+	       va_arg(*args, float*), &size) != 1)
 	return XDS_ERR_TYPE_MISMATCH;
-    else
+    else {
+        *used_buffer_size = size;
 	return XDS_OK;
     }
+}
 
 /*
  * Encode/decode double-precision floating point values.
@@ -464,12 +467,15 @@ int xml_decode_double(xds_t *xds, void *engine_context,
                       void *buffer, size_t buffer_size,
                       size_t *used_buffer_size, va_list *args)
 {
+    int size;
     xds_init_decoding_engine(8 + 9 + 1);
     if (sscanf(buffer, "<double>%lf</double>%n",
-	       va_arg(*args, double*), used_buffer_size) != 1)
+	       va_arg(*args, double*), &size) != 1)
 	return XDS_ERR_TYPE_MISMATCH;
-    else
+    else {
+        *used_buffer_size = size;
 	return XDS_OK;
+    }
 }
 
 /*
